==> jc-1.4.0.tar.gz: javax/swing/text/TabStop.h <==
// public class javax.swing.text.TabStop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b487e54210d0d8b6 javax_swing_text_TabStop

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_TabStop_H_
#define _JC_javax_swing_text_TabStop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_TabStop$sub_refs	_jc_javax_swing_text_TabStop$sub_refs;
typedef struct _jc_javax_swing_text_TabStop$sub_nonrefs	_jc_javax_swing_text_TabStop$sub_nonrefs;
typedef struct _jc_javax_swing_text_TabStop$refs	_jc_javax_swing_text_TabStop$refs;
typedef struct _jc_javax_swing_text_TabStop$nonrefs	_jc_javax_swing_text_TabStop$nonrefs;
typedef struct _jc_javax_swing_text_TabStop$object	_jc_javax_swing_text_TabStop$object;

typedef struct _jc_javax_swing_text_TabStop$fields_struct	_jc_javax_swing_text_TabStop$fields_struct;
typedef const struct _jc_javax_swing_text_TabStop$vmethods	_jc_javax_swing_text_TabStop$vmethods;
typedef const struct _jc_javax_swing_text_TabStop$vtable	_jc_javax_swing_text_TabStop$vtable;
typedef const struct _jc_javax_swing_text_TabStop$vtype	_jc_javax_swing_text_TabStop$vtype;

// Class fields structure
struct _jc_javax_swing_text_TabStop$fields_struct {
	jint	ALIGN__5fBAR;
	jint	ALIGN__5fCENTER;
	jint	ALIGN__5fDECIMAL;
	jint	ALIGN__5fLEFT;
	jint	ALIGN__5fRIGHT;
	jint	LEAD__5fDOTS;
	jint	LEAD__5fEQUALS;
	jint	LEAD__5fHYPHENS;
	jint	LEAD__5fNONE;
	jint	LEAD__5fTHICKLINE;
	jint	LEAD__5fUNDERLINE;
};
extern _jc_javax_swing_text_TabStop$fields_struct _jc_javax_swing_text_TabStop$class_fields;

// Constructors
extern void _jc_javax_swing_text_TabStop$method$_init$6641b0bc5c619f68(_jc_env *, struct _jc_javax_swing_text_TabStop$object *, jfloat);
extern void _jc_javax_swing_text_TabStop$method$_init$a5701fd949570700(_jc_env *, struct _jc_javax_swing_text_TabStop$object *, jfloat, jint, jint);

// Virtual methods
extern jboolean _jc_javax_swing_text_TabStop$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_swing_text_TabStop$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_javax_swing_text_TabStop$method$getAlignment$e688bf6ab07808bc(_jc_env *, struct _jc_javax_swing_text_TabStop$object *);
extern jint _jc_javax_swing_text_TabStop$method$getLeader$dce41b902af0aba8(_jc_env *, struct _jc_javax_swing_text_TabStop$object *);
extern jfloat _jc_javax_swing_text_TabStop$method$getPosition$2162ce3918c4e407(_jc_env *, struct _jc_javax_swing_text_TabStop$object *);
extern jint _jc_javax_swing_text_TabStop$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_swing_text_TabStop$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_text_TabStop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_swing_text_TabStop$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_TabStop$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_swing_text_TabStop$method_info$getAlignment$e688bf6ab07808bc;
extern _jc_method _jc_javax_swing_text_TabStop$method_info$getLeader$dce41b902af0aba8;
extern _jc_method _jc_javax_swing_text_TabStop$method_info$getPosition$2162ce3918c4e407;
extern _jc_method _jc_javax_swing_text_TabStop$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_swing_text_TabStop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_swing_text_TabStop$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_swing_text_TabStop$object *, struct _jc_java_lang_Object$object *);
	jint	(*getAlignment$e688bf6ab07808bc)(_jc_env *, struct _jc_javax_swing_text_TabStop$object *);
	jint	(*getLeader$dce41b902af0aba8)(_jc_env *, struct _jc_javax_swing_text_TabStop$object *);
	jfloat	(*getPosition$2162ce3918c4e407)(_jc_env *, struct _jc_javax_swing_text_TabStop$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_swing_text_TabStop$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_swing_text_TabStop$object *);
};

// Vtable
struct _jc_javax_swing_text_TabStop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_TabStop$vmethods	javax_swing_text_TabStop;
};

// Vtype
struct _jc_javax_swing_text_TabStop$vtype {
	_jc_type			type;
	_jc_javax_swing_text_TabStop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_TabStop$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_TabStop$refs {
    _jc_javax_swing_text_TabStop$sub_refs	javax_swing_text_TabStop;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_TabStop$sub_nonrefs {
	jfloat	pos;
	jint	align;
	jint	leader;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_TabStop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_TabStop$sub_nonrefs	javax_swing_text_TabStop;
};

// Object instance structure
struct _jc_javax_swing_text_TabStop$object {
	_jc_javax_swing_text_TabStop$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_TabStop$vtype	*vtype;
	_jc_javax_swing_text_TabStop$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_TabStop$vtype _jc_javax_swing_text_TabStop$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_TabStop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_TabStop$class_object;

#endif	/* _JC_javax_swing_text_TabStop_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/TabStop.h <==
// public class javax.swing.text.TabStop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b487e54210d0d8b6 javax_swing_text_TabStop

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_TabStop_H_
#define _JC_javax_swing_text_TabStop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_TabStop$sub_refs	_jc_javax_swing_text_TabStop$sub_refs;
typedef struct _jc_javax_swing_text_TabStop$sub_nonrefs	_jc_javax_swing_text_TabStop$sub_nonrefs;
typedef struct _jc_javax_swing_text_TabStop$refs	_jc_javax_swing_text_TabStop$refs;
typedef struct _jc_javax_swing_text_TabStop$nonrefs	_jc_javax_swing_text_TabStop$nonrefs;
typedef struct _jc_javax_swing_text_TabStop$object	_jc_javax_swing_text_TabStop$object;

typedef struct _jc_javax_swing_text_TabStop$fields_struct	_jc_javax_swing_text_TabStop$fields_struct;
typedef const struct _jc_javax_swing_text_TabStop$vmethods	_jc_javax_swing_text_TabStop$vmethods;
typedef const struct _jc_javax_swing_text_TabStop$vtable	_jc_javax_swing_text_TabStop$vtable;
typedef const struct _jc_javax_swing_text_TabStop$vtype	_jc_javax_swing_text_TabStop$vtype;

// Class fields structure
struct _jc_javax_swing_text_TabStop$fields_struct {
	jint	ALIGN__5fBAR;
	jint	ALIGN__5fCENTER;
	jint	ALIGN__5fDECIMAL;
	jint	ALIGN__5fLEFT;
	jint	ALIGN__5fRIGHT;
	jint	LEAD__5fDOTS;
	jint	LEAD__5fEQUALS;
	jint	LEAD__5fHYPHENS;
	jint	LEAD__5fNONE;
	jint	LEAD__5fTHICKLINE;
	jint	LEAD__5fUNDERLINE;
};
extern _jc_javax_swing_text_TabStop$fields_struct _jc_javax_swing_text_TabStop$class_fields;

// Constructors
extern void _jc_javax_swing_text_TabStop$method$_init$6641b0bc5c619f68(_jc_env *, struct _jc_javax_swing_text_TabStop$object *, jfloat) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_TabStop$method$_init$a5701fd949570700(_jc_env *, struct _jc_javax_swing_text_TabStop$object *, jfloat, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_swing_text_TabStop$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_swing_text_TabStop$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_TabStop$method$getAlignment$e688bf6ab07808bc(_jc_env *, struct _jc_javax_swing_text_TabStop$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_TabStop$method$getLeader$dce41b902af0aba8(_jc_env *, struct _jc_javax_swing_text_TabStop$object *) _JC_JCNI_ATTR;
extern jfloat _jc_javax_swing_text_TabStop$method$getPosition$2162ce3918c4e407(_jc_env *, struct _jc_javax_swing_text_TabStop$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_TabStop$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_swing_text_TabStop$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_text_TabStop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_swing_text_TabStop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_TabStop$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_swing_text_TabStop$method_info$getAlignment$e688bf6ab07808bc;
extern _jc_method _jc_javax_swing_text_TabStop$method_info$getLeader$dce41b902af0aba8;
extern _jc_method _jc_javax_swing_text_TabStop$method_info$getPosition$2162ce3918c4e407;
extern _jc_method _jc_javax_swing_text_TabStop$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_swing_text_TabStop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_swing_text_TabStop$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_swing_text_TabStop$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*getAlignment$e688bf6ab07808bc)(_jc_env *, struct _jc_javax_swing_text_TabStop$object *) _JC_JCNI_ATTR;
	jint	(*getLeader$dce41b902af0aba8)(_jc_env *, struct _jc_javax_swing_text_TabStop$object *) _JC_JCNI_ATTR;
	jfloat	(*getPosition$2162ce3918c4e407)(_jc_env *, struct _jc_javax_swing_text_TabStop$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_swing_text_TabStop$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_swing_text_TabStop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_TabStop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_TabStop$vmethods	javax_swing_text_TabStop;
};

// Vtype
struct _jc_javax_swing_text_TabStop$vtype {
	_jc_type			type;
	_jc_javax_swing_text_TabStop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_TabStop$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_TabStop$refs {
    _jc_javax_swing_text_TabStop$sub_refs	javax_swing_text_TabStop;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_TabStop$sub_nonrefs {
	jfloat	pos;
	jint	align;
	jint	leader;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_TabStop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_TabStop$sub_nonrefs	javax_swing_text_TabStop;
};

// Object instance structure
struct _jc_javax_swing_text_TabStop$object {
	_jc_javax_swing_text_TabStop$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_TabStop$vtype	*vtype;
	_jc_javax_swing_text_TabStop$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_TabStop$vtype _jc_javax_swing_text_TabStop$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_TabStop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_TabStop$class_object;

#endif	/* _JC_javax_swing_text_TabStop_H_ */
